@@ -5,8 +5,8 @@ Text::Same::ChunkedSource
 =head1 DESCRIPTION
 
 Objects of this class represent a source of chunks (generally lines)
-in one file and a group of chunks in another.  The "chunks" could
-potentially be paragraphs or sentences.
+in a source (generally a file).  The "chunks" could potentially be
+paragraphs or sentences.
 
 =head1 SYNOPSIS
 
@@ -26,7 +26,7 @@ use strict;
 use Carp;
 
 use vars qw($VERSION);
-$VERSION = '0.04';
+$VERSION = '0.05';
 
 use Digest::MD5 qw(md5);
 
@@ -230,10 +230,10 @@ sub get_matching_chunk_indexes
   return @{$chunk_hash->{hash($options, $text)} || []};
 }
 
-=head2 get_filtered_indx_from_real
+=head2 _get_filtered_indx_from_real
 
- Title   : get_filtered_indx_from_real
- Usage   : $indx = $source->get_filtered_indx_from_real($options, $real_indx);
+ Title   : _get_filtered_indx_from_real
+ Usage   : $indx = $source->_get_filtered_indx_from_real($options, $real_indx);
  Function: for the given index (eg. line number) in this source, return the
            corresponding index in the list of chunks generated by applying the
            $options.  For example if $options->{ignore_blanks} is true the
@@ -253,7 +253,7 @@ sub get_matching_chunk_indexes
 
 =cut
 
-sub get_filtered_indx_from_real
+sub _get_filtered_indx_from_real
 {
   my $self = shift;
   my $options = shift;
@@ -266,28 +266,6 @@ sub get_filtered_indx_from_real
   return $self->{real_to_filtered}{$key}{$real_indx};
 }
 
-=head2 get_real_indx_from_filtered
-
- Title : get_real_indx_from_filtered
- Usage : $indx = $source->get_real_indx_from_filtered($options, $filtrd_indx);
- Func  : return the real index in the source that cooresponds to the given
-         filtered index.  See discussion above.
-
-=cut
-
-sub get_real_indx_from_filtered
-{
-  my $self = shift;
-  my $options = shift;
-  my $filtered_indx = shift;
-
-  my $key = $self->_get_map_key_from_options($options);
-
-  $self->_maybe_make_filtered_maps($options);
-
-  return $self->{real_to_filtered}{$key}{$filtered_indx};
-}
-
 =head2 get_previous_chunk_indx
 
  Title   : get_previous_chunk_indx
@@ -305,7 +283,7 @@ sub get_previous_chunk_indx
   my $chunk_indx = shift;
 
   my $prev_filtered_indx =
-    $self->get_filtered_indx_from_real($options, $chunk_indx) - 1;
+    $self->_get_filtered_indx_from_real($options, $chunk_indx) - 1;
 
   if ($prev_filtered_indx < 0) {
     return undef;
@@ -331,7 +309,7 @@ sub get_next_chunk_indx
   my $chunk_indx = shift;
 
   my $next_filtered_indx =
-    $self->get_filtered_indx_from_real($options, $chunk_indx) + 1;
+    $self->_get_filtered_indx_from_real($options, $chunk_indx) + 1;
 
   if ($next_filtered_indx >= $self->get_all_chunks_count()) {
     return undef;
